# ngChat Speech to Text and Text to Speech SDK

## Next Generation Chat

### Welcome to ngChat, a revolutionary enterprise conversational platform that aims to:

1. addressing issues from the first version of NLU/ChatFlow, and
2. adding significant new features that support enterprise dialogue applications for the next 5 years.

### Our near term goals include:

1. Make developing a chatbot more developer-friendly, e.g., including text-based version control and a DSL language for chatbot definition.
2. Support multilingual on both backend (NLU) and frontend (UI).
3. Construct a mature CI/CD pipeline for both in-the-cloud and on-premise deployment (separate or hybrid), also fix the previous errors of using both MongoDB and SQL.
4. Add STT and TTS support, with connectors to Twilio's cloud communication platform.

### To know more, please visit [Seasalt.ai](https://seasalt.ai/)
